@@ -1,26 +1,26 @@
 
 #define HOST_CPU "i386"
 #define HOST_VENDOR "pc"
-#define HOST_OS "solaris2.6"
+#define HOST_OS "solaris2.7"
 #define HOST_OS_NAME "solaris2"
-#define HOST_OS_VERSION "2.6"
+#define HOST_OS_VERSION "2.7"
 #define HOST_ARCH "i86pc"
-#define HOST_NAME "goofy.cs.columbia.edu"
+#define HOST_NAME "iguana.mcl.cs.columbia.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Tue Jul  4 17:20:23 EDT 2000"
+#define CONFIG_DATE "Sat May 27 20:18:04 EDT 2000"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.4s6"
+#define VERSION "6.0.4s4"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.4s6"
+#define VERSION "6.0.4s4"
 #define DEBUG 1
-#define HOST_HEADER_VERSION "2.6"
+#define HOST_HEADER_VERSION "2.7"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
-#define HAVE_LIBPOSIX4 1
+#define HAVE_LIBLDAP 1
+#define HAVE_LIBRT 1
 #define HAVE_ALLOCA_H 1
 #define HAVE_ALLOCA 1
 #define STDC_HEADERS 1
-#define HAVE_WAIT3 1
 #define HAVE___SETERR_REPLY 1
 #define HAVE_BCMP 1
 #define HAVE_BCOPY 1
@@ -37,6 +37,7 @@
 #define HAVE_GETPAGESIZE 1
 #define HAVE_GETTIMEOFDAY 1
 #define HAVE_HASMNTOPT 1
+#define HAVE_LDAP_OPEN 1
 #define HAVE_MEMCMP 1
 #define HAVE_MEMCPY 1
 #define HAVE_MEMMOVE 1
@@ -152,6 +153,8 @@
 #define HAVE_ERRNO_H 1
 #define HAVE_FCNTL_H 1
 #define HAVE_GRP_H 1
+#define HAVE_LBER_H 1
+#define HAVE_LDAP_H 1
 #define HAVE_LIBGEN_H 1
 #define HAVE_MALLOC_H 1
 #define HAVE_MEMORY_H 1
@@ -176,7 +179,7 @@
 #define HAVE_VARARGS_H 1
 #define HAVE_UNISTD_H 1
 #define TIME_WITH_SYS_TIME 1
-#define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_sunos5_6.h"
+#define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_sunos5_7.h"
 #define HAVE_STRUCT_MNTTAB 1
 #define HAVE_STRUCT_NFS_ARGS 1
 #define nfs_args_t struct nfs_args
@@ -222,6 +225,7 @@
 #define HAVE_EXTERN_WAIT3 1
 #define HAVE_EXTERN_VSNPRINTF 1
 #define HAVE_LONG_FILE_NAMES 1
+#define HAVE_UNISTD_H 1
 #define HAVE_TRANSPORT_TYPE_TLI 1
 #define HAVE_FIELD_MNTENT_T_MNT_TIME 1
 #define HAVE_FIELD_MNTENT_T_MNT_TIME_STRING 1
@@ -233,6 +237,7 @@
 #define HAVE_FIELD_NFS_ARGS_T_ACREGMIN 1
 #define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
 #define HAVE_MAP_FILE 1
+#define HAVE_MAP_LDAP 1
 #define HAVE_MAP_NDBM 1
 #define HAVE_MAP_NIS 1
 #define HAVE_MAP_NISPLUS 1
@@ -307,6 +312,7 @@
 #define MNT2_GEN_OPT_DATA 0x4
 #define MNT2_GEN_OPT_FSS 0x2
 #define MNT2_GEN_OPT_NOSUID 0x10
+#define MNT2_GEN_OPT_OPTIONSTR 0x100
 #define MNT2_GEN_OPT_OVERLAY 0x80
 #define MNT2_GEN_OPT_RDONLY 0x1
 #define MNT2_NFS_OPT_ACDIRMAX 0x800
